Struct
QmiMessageNasIncrementalNetworkScanInput
since: 1.38
Description [src]
struct QmiMessageNasIncrementalNetworkScanInput {
/* No available fields */
}
The QmiMessageNasIncrementalNetworkScanInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.38
Constructors
qmi_message_nas_incremental_network_scan_input_new
Allocates a new QmiMessageNasIncrementalNetworkScanInput.
since: 1.38
Instance methods
qmi_message_nas_incremental_network_scan_input_get_network_type
Get the ‘Network Type’ field from self.
since: 1.0
qmi_message_nas_incremental_network_scan_input_ref
Atomically increments the reference count of self by one.
since: 1.38
qmi_message_nas_incremental_network_scan_input_set_network_type
Set the ‘Network Type’ field in the message.
since: 1.0
qmi_message_nas_incremental_network_scan_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.38